--TEST--
__construct()
--FILE--
<?php
    /*
     * NOTE:
     * Because the constructor calls open(), and because open() in turn calls
     * _readHeader(), and because test 5 causes _readHeader() to call
     * _computeHeader(), this test then acts as a test for each of those
     * methods.
     */
    error_reporting(0);
    require_once dirname(__FILE__) . '/setup.php.inc';

    echo "Test 1: no parameters\n";
    $f = new File_Fortune();
    if (is_a($f, 'File_Fortune')) {
        echo "Success\n";
    } else {
        echo "Failed\n";
    }
    unset($f);

    echo "Test 2: Fortune file only\n";
    try {
        $f = new File_Fortune($FILE);
        echo "Success\n";
    } catch (File_Fortune_Exception $e) {
       echo "Failed!\n";
    }
    unset($f);

    echo "Test 3: Fortune and header file\n";
    try {
        $f = new File_Fortune($FILE, $HFILE);
        echo "Success\n";
    } catch (File_Fortune_Exception $e) {
        echo "Failed\n";
    }
    unset($f);

    echo "Test 4: Bad fortune file\n";
    try {
        $f = new File_Fortune('bogus');
        echo "Failed\n";
    } catch (File_Fortune_Exception $e) {
        echo "Success\n";
    }
    unset($f);

    echo "Test 5: Good fortune file, non-existent header file\n";
    try {
        // This should succeed because if the bogus header file is not present,
        // it defaults to using the fortune file itself to compute the headers.
        $f = new File_Fortune($FILE, 'bogus');
        echo "Success\n";
    } catch (File_Fortune_Exception $e) {
        echo "Failed\n";
        echo $e->getMessage(), "\n";
    }
    unset($f);

    echo "Test 6: Good fortune file, bad header file\n";
    try {
        // This should fail, because the supposed header file is not formed
        // correctly
        $f = new File_Fortune($FILE, $FILE);
        echo "Failure\n";
    } catch (File_Fortune_Exception $e) {
        echo "Success\n";
    }
    unset($f);

?>
--EXPECT--
Test 1: no parameters
Success
Test 2: Fortune file only
Success
Test 3: Fortune and header file
Success
Test 4: Bad fortune file
Success
Test 5: Good fortune file, non-existent header file
Success
Test 6: Good fortune file, bad header file
Success

